@@ -142,10 +142,23 @@ computePMDs <- function(methylationData,
     # Force serial execution
     BPPARAM <- BiocParallel::SerialParam(progressbar = TRUE)
   }
-  if (!is.null(cores)){
-    .stopIfNotAll(c(.isInteger(cores, positive=TRUE)), 
-                  " the number of cores to used when computing the DMRs needs to be an integer  hirger or equal to 1.")
-    .stopIfNotAll(BPPARAM$workers >= cores, paste0("the cores should be smaller than system's cores, current system cores: ",BPPARAM$workers))
+  # If cores argument is specified
+  if (!is.null(cores)) {
+    .stopIfNotAll(.isInteger(cores, positive = TRUE), 
+                  "the number of cores used when computing the DMRs needs to be an integer higher or equal to 1.")
+    
+    # Check if user requested more cores than available
+    if (cores > BPPARAM$workers) {
+      warning(paste0("The number of requested cores (", cores, 
+                     ") exceeds the available system cores (", BPPARAM$workers, 
+                     "). Automatically setting cores to the maximum available (", 
+                     BPPARAM$workers, ")."))
+      cores <- BPPARAM$workers
+    } else {
+      message(paste0("Using user-specified core count: ", cores))
+    }
+    
+    # Apply the final core number
     BPPARAM$workers <- cores
   } else {
     cores <- BPPARAM$workers
@@ -711,10 +724,23 @@ filterPMDs <- function(methylationData,
     # Force serial execution
     BPPARAM <- BiocParallel::SerialParam(progressbar = TRUE)
   }
-  if (!is.null(cores)){
-    .stopIfNotAll(c(.isInteger(cores, positive=TRUE)), 
-                  " the number of cores to used when computing the DMRs needs to be an integer  hirger or equal to 1.")
-    .stopIfNotAll(BPPARAM$workers >= cores, paste0("the cores should be smaller than system's cores, current system cores: ",BPPARAM$workers))
+  # If cores argument is specified
+  if (!is.null(cores)) {
+    .stopIfNotAll(.isInteger(cores, positive = TRUE), 
+                  "the number of cores used when computing the DMRs needs to be an integer higher or equal to 1.")
+    
+    # Check if user requested more cores than available
+    if (cores > BPPARAM$workers) {
+      warning(paste0("The number of requested cores (", cores, 
+                     ") exceeds the available system cores (", BPPARAM$workers, 
+                     "). Automatically setting cores to the maximum available (", 
+                     BPPARAM$workers, ")."))
+      cores <- BPPARAM$workers
+    } else {
+      message(paste0("Using user-specified core count: ", cores))
+    }
+    
+    # Apply the final core number
     BPPARAM$workers <- cores
   } else {
     cores <- BPPARAM$workers
@@ -928,10 +954,23 @@ mergePMDsIteratively <- function(PMDs,
     # Force serial execution
     BPPARAM <- BiocParallel::SerialParam(progressbar = TRUE)
   }
-  if (!is.null(cores)){
-    .stopIfNotAll(c(.isInteger(cores, positive=TRUE)), 
-                  " the number of cores to used when computing the DMRs needs to be an integer  hirger or equal to 1.")
-    .stopIfNotAll(BPPARAM$workers >= cores, paste0("the cores should be smaller than system's cores, current system cores: ",BPPARAM$workers))
+  # If cores argument is specified
+  if (!is.null(cores)) {
+    .stopIfNotAll(.isInteger(cores, positive = TRUE), 
+                  "the number of cores used when computing the DMRs needs to be an integer higher or equal to 1.")
+    
+    # Check if user requested more cores than available
+    if (cores > BPPARAM$workers) {
+      warning(paste0("The number of requested cores (", cores, 
+                     ") exceeds the available system cores (", BPPARAM$workers, 
+                     "). Automatically setting cores to the maximum available (", 
+                     BPPARAM$workers, ")."))
+      cores <- BPPARAM$workers
+    } else {
+      message(paste0("Using user-specified core count: ", cores))
+    }
+    
+    # Apply the final core number
     BPPARAM$workers <- cores
   } else {
     cores <- BPPARAM$workers
@@ -1042,10 +1081,23 @@ analyseReadsInsideRegionsForConditionPMD <- function(regions,
     # Force serial execution
     BPPARAM <- BiocParallel::SerialParam(progressbar = TRUE)
   }
-  if (!is.null(cores)){
-    .stopIfNotAll(c(.isInteger(cores, positive=TRUE)), 
-                  " the number of cores to used when computing the DMRs needs to be an integer  hirger or equal to 1.")
-    .stopIfNotAll(BPPARAM$workers >= cores, paste0("the cores should be smaller than system's cores, current system cores: ",BPPARAM$workers))
+  # If cores argument is specified
+  if (!is.null(cores)) {
+    .stopIfNotAll(.isInteger(cores, positive = TRUE), 
+                  "the number of cores used when computing the DMRs needs to be an integer higher or equal to 1.")
+    
+    # Check if user requested more cores than available
+    if (cores > BPPARAM$workers) {
+      warning(paste0("The number of requested cores (", cores, 
+                     ") exceeds the available system cores (", BPPARAM$workers, 
+                     "). Automatically setting cores to the maximum available (", 
+                     BPPARAM$workers, ")."))
+      cores <- BPPARAM$workers
+    } else {
+      message(paste0("Using user-specified core count: ", cores))
+    }
+    
+    # Apply the final core number
     BPPARAM$workers <- cores
   } else {
     cores <- BPPARAM$workers
